@@ -3,11 +3,15 @@
 # Shell script for Default command list for aproot from Nadeko/ananadeko_linkdef.h
 #
 INFILE="../Nadeko/ananadeko_linkdef.h"
-OUTFILE=$1
+HEADFILE="src/AnapawMode.cc.head"
+OUTFILE="src/AnapawMode.cc"
+
+cp -f $HEADFILE $OUTFILE
 
 MATCH="#pragma link C++ function "
 
-echo "void AnapawMode::SetDefaultComList(){" > $OUTFILE
+cat $HEADFILE > $OUTFILE
+echo "void AnapawMode::SetDefaultComList(){" >> $OUTFILE
 
 while read LINE; do
 # extract command word from matched line
